Index: webrtc/base/thread.cc |
diff --git a/webrtc/base/thread.cc b/webrtc/base/thread.cc |
index af5e68bedf81234704fa3d8e611d196f13865b90..5278c9321eae369167fb5717d5be84c6caa16021 100644 |
--- a/webrtc/base/thread.cc |
+++ b/webrtc/base/thread.cc |
@@ -218,7 +218,7 @@ |
ASSERT(!running()); |
if (running()) return false; |
- Restart(); // reset IsQuitting() if the thread is being restarted |
+ Restart(); // reset fStop_ if the thread is being restarted |
// Make sure that ThreadManager is created on the main thread before |
// we start a new thread. |
@@ -346,7 +346,7 @@ |
MessageHandler* phandler, |
uint32_t id, |
MessageData* pdata) { |
- if (IsQuitting()) |
+ if (fStop_) |
return; |
// Sent messages are sent to the MessageHandler directly, in the context |